"""
isicarchive variables

constants
---------
ISIC_API_URI : str
    current API URI
ISIC_BASE_URL : str
    hostname of ISIC Archive, including https:// protocol id
"""

__version__ = '0.3.5'
ISIC_API_URI = '/api/v1'
ISIC_BASE_URL = 'https://isic-archive.com'
